@@ -3,20 +3,19 @@ package App::Condition::IsCreator;
 
 
 use strict;
-use base qw( Workflow::Condition );
-use Log::Log4perl       qw( get_logger );
-use Workflow::Exception qw( condition_error );
+use parent qw( Workflow::Condition );
+use Log::Any qw( $log );
+use Workflow::Condition::IsFalse;
+use Workflow::Condition::IsTrue;
 use Workflow::Factory   qw( FACTORY );
 
 $App::Condition::IsCreator::VERSION = '1.02';
 
-my ( $log );
-
 my ( $FACTORY );
 
 sub evaluate {
     my ( $self, $wf ) = @_;
-    $log ||= get_logger();
+
     $log->debug( "Trying to execute condition ", ref( $self ) );
 
     # First see that we have both a user and ticket...
@@ -29,8 +28,9 @@ sub evaluate {
     $log->debug( "Current user in the context is '", $current_user, "' ",
                  "ticket creator is '", $ticket->creator, "'" );
     unless ( $ticket->creator eq $current_user ) {
-        condition_error "User is not the creator of the ticket";
+        return Workflow::Condition::IsFalse->new();
     }
+    return Workflow::Condition::IsTrue->new();
 }
 
 1;
